##  Using Workspace Views
To apply a workspace view, select it from the list on the right side of the navigation bar, next to the fact sheet search field. The workspace reloads, showing filtered data. You can switch between workspace views as needed, depending on your current focus and tasks. To go back to the unfiltered view, select Full View.
Here are some best practices and tips for workspace views:
  * Focus on one task at a time by selecting a relevant view.
  * Once you select a view, you can apply additional filters and perform other actions as usual.
  * To foster collaboration, copy the link to a view from the list.
